libcap is UN*X-only; libnl is Linux-only.
[metze/wireshark/wip.git] / file.h
diff --git a/file.h b/file.h
index b1f20530f73d64f461f39730f2c1fafb177f6319..e375a196f1a742bd906c0fc6bc6a97c675fe059c 100644 (file)
--- a/file.h
+++ b/file.h
 #define __FILE_H__
 
 #include "wiretap/wtap.h"
-#include "print.h"
 #include <errno.h>
 #include <epan/epan.h>
 
-#include "packet-range.h"
+#include <epan/print.h>
+#include <epan/packet-range.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -148,7 +148,7 @@ cf_read_status_t cf_read(capture_file *cf, gboolean from_save);
  * @param buf a Buffer into which to read the packet's raw data
  * @return TRUE if the read succeeded, FALSE if there was an error
  */
-gboolean cf_read_frame_r(capture_file *cf, frame_data *fdata,
+gboolean cf_read_frame_r(capture_file *cf, const frame_data *fdata,
                          struct wtap_pkthdr *phdr, Buffer *buf);
 
 /**
@@ -162,18 +162,6 @@ gboolean cf_read_frame_r(capture_file *cf, frame_data *fdata,
  */
 gboolean cf_read_frame(capture_file *cf, frame_data *fdata);
 
-/**
- * Start reading from the end of a capture file.
- * This is used in "Update list of packets in Real-Time".
- *
- * @param cf the capture file to be read from
- * @param fname the filename to be read from
- * @param is_tempfile is this a temporary file?
- * @param err the error code, if an error had occurred
- * @return one of cf_status_t
- */
-cf_status_t cf_start_tail(capture_file *cf, const char *fname, gboolean is_tempfile, int *err);
-
 /**
  * Read packets from the "end" of a capture file.
  *
@@ -392,7 +380,7 @@ void cf_reftime_packets(capture_file *cf);
 /**
  * Return the time it took to load the file
  */
-gulong cf_get_computed_elapsed(void);
+gulong cf_get_computed_elapsed(capture_file *cf);
 
 /**
  * "Something" has changed, rescan all packets.
@@ -667,14 +655,16 @@ const gchar* cf_read_shb_comment(capture_file *cf);
  */
 void cf_update_capture_comment(capture_file *cf, gchar *comment);
 
+char *cf_get_comment(capture_file *cf, const frame_data *fd);
+
 /**
  * Update(replace) the comment on a capture from a frame
  *
  * @param cf the capture file
* @param fdata the frame_data structure for the frame
* @param comment the string replacing the old comment
  */
-void cf_update_packet_comment(capture_file *cf, frame_data *fdata, gchar *comment);
+gboolean cf_set_user_packet_comment(capture_file *cf, frame_data *fd, const gchar *new_comment);
 
 /**
  * What types of comments does this file have?
@@ -667,14 +655,16 @@ const gchar* cf_read_shb_comment(capture_file *cf);
  *
  * @param cf the capture file
- * @param fdata the frame_data structure for the frame
- * @param comment the string replacing the old comment
+ * @param fd the frame_data structure for the frame
+ * @param new_comment the string replacing the old comment
  */